sketch

package
v0.21.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 5, 2026 License: MIT Imports: 15 Imported by: 0

Documentation

Index

Constants

const BinaryName = "sketchlib"

Variables

This section is empty.

Functions

func FindBinary

func FindBinary() (string, error)

FindBinary locates the sketchlib binary. Search order: 1. Same directory as the running atb binary 2. System PATH If not found, returns an error with install instructions.

func InstallBinary

func InstallBinary(progress func(string)) error

InstallBinary downloads the sketchlib binary from GitHub releases and places it alongside the atb binary. Returns the installed path.

func SketchQuery

func SketchQuery(inputs []string, kmerSizes []int, threads int) (tmpDir, prefix string, err error)

Types

type DatabaseInfo

type DatabaseInfo struct {
	Samples    int
	KmerSizes  []int
	SketchSize int
}

func Info

func Info(skmPath string) (*DatabaseInfo, error)

func ParseInfo

func ParseInfo(r io.Reader) (*DatabaseInfo, error)

type Match

type Match struct {
	RefName   string
	QueryName string
	ANI       float64
}

func ParseDistOutput

func ParseDistOutput(r io.Reader) ([]Match, error)

func QueryDist

func QueryDist(refPrefix, queryPrefix string, kmer, threads, topN int) ([]Match, error)

Jump to